.. ehrcorral documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. |br| raw:: html

   <br />

Welcome to EHRCorral's documentation!
=====================================

EHRCorral creates a master patient index (MPI) by matching and linking
electronic medical records.

**EHR** |br|
noun (electronic healtchare record) |br|
1. a health record in digital format: *the patient's medical diagnosis was
entered into the EHR.*

**corral** \|kəˈral| |br|
verb (corrals, corralling, corralled) [ with obj. ] |br|
1. gather together and confine (a group of people or things): *the
organizers were corralling the crowd into marching formation.*

.. toctree::
   :maxdepth: 2

   EHRCorral <readme>
   overview
   installation
   usage
   modules
   contributing
   project

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

